==> jupyterlab_scheduler-0.1.3.tar.gz: package/lib/ShowJobs.js <==
"use strict";

require("core-js/modules/es.symbol");

require("core-js/modules/es.symbol.description");

require("core-js/modules/es.symbol.iterator");

require("core-js/modules/es.array.filter");

require("core-js/modules/es.array.for-each");

require("core-js/modules/es.array.iterator");

require("core-js/modules/es.array.map");

require("core-js/modules/es.date.to-string");

require("core-js/modules/es.object.create");

require("core-js/modules/es.object.define-property");

require("core-js/modules/es.object.get-prototype-of");

require("core-js/modules/es.object.set-prototype-of");

require("core-js/modules/es.object.to-string");

require("core-js/modules/es.promise");

require("core-js/modules/es.reflect.construct");

require("core-js/modules/es.regexp.to-string");

require("core-js/modules/es.string.iterator");

require("core-js/modules/web.dom-collections.for-each");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ViewScheduledJobs = void 0;

require("regenerator-runtime/runtime");

var _apputils = require("@jupyterlab/apputils");

var _api = require("./api");

var _ViewLog = require("./ViewLog");

var _react = _interopRequireDefault(require("react"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var Jobs = /*#__PURE__*/function (_React$Component) {
  _inherits(Jobs, _React$Component);

  var _super = _createSuper(Jobs);

  function Jobs() {
    var _this;

    _classCallCheck(this, Jobs);

    _this = _super.call(this);
    _this.state = {
      jobs: []
    };
    return _this;
  }

  _createClass(Jobs, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.getScheduledJobs();
    }
  }, {
    key: "openLog",
    value: function openLog(schedule, command) {
      // Create widget for displaying jobs & attach
      var content = new _ViewLog.ViewLog(command, schedule);
      var widget = new _apputils.MainAreaWidget({
        content: content
      });
      widget.title.label = "Log - ".concat(command);
      widget.title.closable = true;
      widget.id = 'scheduled-job-log';
      this.props.shell.add(widget, 'main');
    }
  }, {
    key: "getScheduledJobs",
    value: function () {
      var _getScheduledJobs = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
        var data;
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                _context.next = 3;
                return (0, _api.requestAPI)('list');

              case 3:
                data = _context.sent;

                if ("data" in data) {
                  this.setState({
                    jobs: data.data
                  });
                }

                console.log("data", data);
                _context.next = 11;
                break;

              case 8:
                _context.prev = 8;
                _context.t0 = _context["catch"](0);
                console.error("Error fetching jobs: ".concat(_context.t0));

              case 11:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[0, 8]]);
      }));

      function getScheduledJobs() {
        return _getScheduledJobs.apply(this, arguments);
      }

      return getScheduledJobs;
    }()
  }, {
    key: "deleteJob",
    value: function () {
      var _deleteJob = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(schedule, command) {
        var dataToSend, reply, jobIndexToRemove, updatedJobs;
        return regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                dataToSend = {
                  command: command,
                  schedule: schedule
                };
                _context2.prev = 1;
                _context2.next = 4;
                return (0, _api.requestAPI)('delete', {
                  body: JSON.stringify(dataToSend),
                  method: 'POST'
                });

              case 4:
                reply = _context2.sent;
                // Delete the item the user selected from the state array
                // Particulary complicated because I had to account for the fact that
                // there may be duplicate jobs & the server is just going to remove the first instance
                jobIndexToRemove = null;
                this.state.jobs.forEach(function (job, i) {
                  if (job.command === command && job.schedule === schedule && jobIndexToRemove === null) {
                    jobIndexToRemove = i;
                  }
                });

                if (jobIndexToRemove !== null) {
                  updatedJobs = this.state.jobs.filter(function (job, i) {
                    return i !== jobIndexToRemove;
                  });
                  this.setState({
                    jobs: updatedJobs
                  });
                }

                _context2.next = 13;
                break;

              case 10:
                _context2.prev = 10;
                _context2.t0 = _context2["catch"](1);
                console.error("Error sending delete: ".concat(_context2.t0));

              case 13:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2, this, [[1, 10]]);
      }));

      function deleteJob(_x, _x2) {
        return _deleteJob.apply(this, arguments);
      }

      return deleteJob;
    }()
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      return /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement("table", {
        style: {
          "border": "1px solid black",
          "borderCollapse": "collapse"
        }
      }, /*#__PURE__*/_react["default"].createElement("thead", null, /*#__PURE__*/_react["default"].createElement("tr", {
        style: {
          "border": "1px solid black"
        }
      }, /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Schedule"), /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Script"), /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Command"), /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Log Location"), /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Log"), /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Delete"))), /*#__PURE__*/_react["default"].createElement("tbody", null, this.state.jobs.map(function (job, i) {
        return /*#__PURE__*/_react["default"].createElement("tr", {
          key: i,
          style: {
            "border": "1px solid black"
          }
        }, /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, job.schedule), /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, job.script), /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, job.command), /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, job.log_file), /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, /*#__PURE__*/_react["default"].createElement("button", {
          onClick: function onClick() {
            _this2.openLog(job.schedule, job.command);
          }
        }, "View")), /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, /*#__PURE__*/_react["default"].createElement("button", {
          onClick: function onClick() {
            _this2.deleteJob(job.schedule, job.command);
          }
        }, "X")));
      }))));
    }
  }]);

  return Jobs;
}(_react["default"].Component);
/**
 * A Lumino Widget that wraps a react component.
 */


var ViewScheduledJobs = /*#__PURE__*/function (_ReactWidget) {
  _inherits(ViewScheduledJobs, _ReactWidget);

  var _super2 = _createSuper(ViewScheduledJobs);

  function ViewScheduledJobs(shell) {
    var _this3;

    _classCallCheck(this, ViewScheduledJobs);

    _this3 = _super2.call(this);

    _this3.addClass('ReactWidget');

    console.log("yo", shell);
    _this3.shell = shell;
    return _this3;
  }

  _createClass(ViewScheduledJobs, [{
    key: "render",
    value: function render() {
      return /*#__PURE__*/_react["default"].createElement(Jobs, {
        dog: "yo",
        shell: this.shell
      });
    }
  }]);

  return ViewScheduledJobs;
}(_apputils.ReactWidget);

exports.ViewScheduledJobs = ViewScheduledJobs;

==> jupyterlab_scheduler-0.1.5.tar.gz: package/lib/ShowJobs.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

require("core-js/modules/es.reflect.construct.js");

require("core-js/modules/es.object.create.js");

require("core-js/modules/es.object.define-property.js");

require("core-js/modules/es.object.to-string.js");

require("core-js/modules/es.promise.js");

require("core-js/modules/es.symbol.js");

require("core-js/modules/es.symbol.description.js");

require("core-js/modules/es.symbol.iterator.js");

require("core-js/modules/es.array.iterator.js");

require("core-js/modules/es.string.iterator.js");

require("core-js/modules/web.dom-collections.iterator.js");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ViewScheduledJobs = void 0;

require("core-js/modules/es.array.for-each.js");

require("core-js/modules/web.dom-collections.for-each.js");

require("core-js/modules/es.array.filter.js");

require("core-js/modules/es.array.map.js");

require("core-js/modules/es.object.set-prototype-of.js");

require("core-js/modules/es.object.get-prototype-of.js");

require("regenerator-runtime/runtime.js");

var _apputils = require("@jupyterlab/apputils");

var _api = require("./api");

var _ViewLog = require("./ViewLog");

var _react = _interopRequireDefault(require("react"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var Jobs = /*#__PURE__*/function (_React$Component) {
  _inherits(Jobs, _React$Component);

  var _super = _createSuper(Jobs);

  function Jobs() {
    var _this;

    _classCallCheck(this, Jobs);

    _this = _super.call(this);
    _this.state = {
      jobs: []
    };
    return _this;
  }

  _createClass(Jobs, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.getScheduledJobs();
    }
  }, {
    key: "openLog",
    value: function openLog(schedule, command) {
      // Create widget for displaying jobs & attach
      var content = new _ViewLog.ViewLog(command, schedule);
      var widget = new _apputils.MainAreaWidget({
        content: content
      });
      widget.title.label = "Log - ".concat(command);
      widget.title.closable = true;
      widget.id = 'scheduled-job-log';
      this.props.shell.add(widget, 'main');
    }
  }, {
    key: "getScheduledJobs",
    value: function () {
      var _getScheduledJobs = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
        var data;
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                _context.next = 3;
                return (0, _api.requestAPI)('list');

              case 3:
                data = _context.sent;

                if ("data" in data) {
                  this.setState({
                    jobs: data.data
                  });
                }

                console.log("data", data);
                _context.next = 11;
                break;

              case 8:
                _context.prev = 8;
                _context.t0 = _context["catch"](0);
                console.error("Error fetching jobs: ".concat(_context.t0));

              case 11:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[0, 8]]);
      }));

      function getScheduledJobs() {
        return _getScheduledJobs.apply(this, arguments);
      }

      return getScheduledJobs;
    }()
  }, {
    key: "deleteJob",
    value: function () {
      var _deleteJob = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(schedule, command) {
        var dataToSend, reply, jobIndexToRemove, updatedJobs;
        return regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                dataToSend = {
                  command: command,
                  schedule: schedule
                };
                _context2.prev = 1;
                _context2.next = 4;
                return (0, _api.requestAPI)('delete', {
                  body: JSON.stringify(dataToSend),
                  method: 'POST'
                });

              case 4:
                reply = _context2.sent;
                // Delete the item the user selected from the state array
                // Particulary complicated because I had to account for the fact that
                // there may be duplicate jobs & the server is just going to remove the first instance
                jobIndexToRemove = null;
                this.state.jobs.forEach(function (job, i) {
                  if (job.command === command && job.schedule === schedule && jobIndexToRemove === null) {
                    jobIndexToRemove = i;
                  }
                });

                if (jobIndexToRemove !== null) {
                  updatedJobs = this.state.jobs.filter(function (job, i) {
                    return i !== jobIndexToRemove;
                  });
                  this.setState({
                    jobs: updatedJobs
                  });
                }

                _context2.next = 13;
                break;

              case 10:
                _context2.prev = 10;
                _context2.t0 = _context2["catch"](1);
                console.error("Error sending delete: ".concat(_context2.t0));

              case 13:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2, this, [[1, 10]]);
      }));

      function deleteJob(_x, _x2) {
        return _deleteJob.apply(this, arguments);
      }

      return deleteJob;
    }()
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      return /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement("table", {
        style: {
          "border": "1px solid black",
          "borderCollapse": "collapse"
        }
      }, /*#__PURE__*/_react["default"].createElement("thead", null, /*#__PURE__*/_react["default"].createElement("tr", {
        style: {
          "border": "1px solid black"
        }
      }, /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Schedule"), /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Script"), /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Command"), /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Log Location"), /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Log"), /*#__PURE__*/_react["default"].createElement("th", {
        style: {
          "border": "1px solid black"
        }
      }, "Delete"))), /*#__PURE__*/_react["default"].createElement("tbody", null, this.state.jobs.map(function (job, i) {
        return /*#__PURE__*/_react["default"].createElement("tr", {
          key: i,
          style: {
            "border": "1px solid black"
          }
        }, /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, job.schedule), /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, job.script), /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, job.command), /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, job.log_file), /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, /*#__PURE__*/_react["default"].createElement("button", {
          onClick: function onClick() {
            _this2.openLog(job.schedule, job.command);
          }
        }, "View")), /*#__PURE__*/_react["default"].createElement("td", {
          style: {
            "border": "1px solid black"
          }
        }, /*#__PURE__*/_react["default"].createElement("button", {
          onClick: function onClick() {
            _this2.deleteJob(job.schedule, job.command);
          }
        }, "X")));
      }))));
    }
  }]);

  return Jobs;
}(_react["default"].Component);
/**
 * A Lumino Widget that wraps a react component.
 */


var ViewScheduledJobs = /*#__PURE__*/function (_ReactWidget) {
  _inherits(ViewScheduledJobs, _ReactWidget);

  var _super2 = _createSuper(ViewScheduledJobs);

  function ViewScheduledJobs(shell) {
    var _this3;

    _classCallCheck(this, ViewScheduledJobs);

    _this3 = _super2.call(this);

    _this3.addClass('ReactWidget');

    _this3.shell = shell;
    return _this3;
  }

  _createClass(ViewScheduledJobs, [{
    key: "render",
    value: function render() {
      return /*#__PURE__*/_react["default"].createElement(Jobs, {
        shell: this.shell
      });
    }
  }]);

  return ViewScheduledJobs;
}(_apputils.ReactWidget);

exports.ViewScheduledJobs = ViewScheduledJobs;
